@@ -33,7 +33,6 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
-#include <syslog.h>
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -50,15 +49,6 @@
 /* Constants for userdefchar_mode */
 #define NUM_CCs		8 /* max. number of custom characters */
 
-typedef enum {
-	standard,	/* only char 0 is used for heartbeat */
-	vbar,		/* vertical bars */
-	hbar,		/* horizontal bars */
-	custom,		/* custom settings */
-	bignum,		/* big numbers */
-	bigchar		/* big characters */
-} CGmode;
-
 /** private data for the \c CFontz driver */
 typedef struct CFontz_private_data {
 	char device[200];
@@ -76,7 +66,7 @@ typedef struct CFontz_private_data {
 	unsigned char *framebuf;
 	unsigned char *backingstore;
 
-	/* defineable characters */
+	/* definable characters */
 	CGmode ccmode;
 
 	int contrast;
@@ -253,6 +243,12 @@ CFontz_init(Driver *drvthis)
 		report(RPT_INFO, "%s: rebooting LCD...", drvthis->name);
 		CFontz_reboot(drvthis);
 	}
+
+#ifndef SEAMLESS_HBARS
+	report(RPT_WARNING, "%s: driver built without SEAMLESS_HBARS. "
+	       "Hbars will NOT display correctly!", drvthis->name);
+#endif
+
 	sleep (1);
 	CFontz_hidecursor(drvthis);
 	CFontz_linewrap(drvthis, 1);
@@ -926,7 +922,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 	/* Yes we know, this is a VERY BAD implementation :-) */
 	switch (icon) {
 		case ICON_BLOCK_FILLED:
-			CFontz_raw_chr(drvthis, x, y, (p->newfirmware) ? 214 : 255);
+			CFontz_raw_chr(drvthis, x, y, (p->newfirmware) ? 0x1F : 255);
 			break;
 		case ICON_HEART_FILLED:
 			CFontz_set_char(drvthis, 0, heart_filled);
