@@ -178,7 +178,6 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
-#include <syslog.h>
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -205,7 +204,7 @@ typedef struct MD8800_private_data {
 	/* framebuffer and buffer for old LCD contents */
 	unsigned char *framebuf;
 	unsigned char *backingstore;
-	/* defineable characters */
+	/* definable characters */
 	int on_brightness;
 	int off_brightness;
 	int hw_brightness;
