@@ -1,8 +1,6 @@
 #ifndef GLK_H
 #define GLK_H
 
-#include "lcd.h"
-
 MODULE_EXPORT int  glk_init(Driver *drvthis);
 MODULE_EXPORT void glk_close(Driver *drvthis);
 MODULE_EXPORT int  glk_width(Driver *drvthis);
@@ -15,6 +13,9 @@ MODULE_EXPORT void glk_string(Driver *drvthis, int x, int y, const char string[]
 MODULE_EXPORT void glk_chr(Driver *drvthis, int x, int y, char c);
 
 MODULE_EXPORT void glk_num(Driver *drvthis, int x, int num);
+MODULE_EXPORT void glk_vbar(Driver *drvthis, int x, int y, int len, int promille, int options);
+MODULE_EXPORT void glk_hbar(Driver *drvthis, int x, int y, int len, int promille, int options);
+MODULE_EXPORT int  glk_icon(Driver *drvthis, int x, int y, int icon);
 
 MODULE_EXPORT int  glk_get_free_chars(Driver *drvthis);
 MODULE_EXPORT void glk_set_char(Driver *drvthis, int n, char *dat);
@@ -26,9 +27,4 @@ MODULE_EXPORT void glk_output(Driver *drvthis, int on);
 
 MODULE_EXPORT const char *glk_get_key(Driver *drvthis);
 
-// Functions using old 0.4 API.
-MODULE_EXPORT void glk_old_vbar(Driver *drvthis, int x, int len);
-MODULE_EXPORT void glk_old_hbar(Driver *drvthis, int x, int y, int len);
-MODULE_EXPORT void glk_old_icon(Driver *drvthis, int which, int dest);
-
 #endif
