@@ -27,18 +27,10 @@
 #include "hd44780-uss720.h"
 #include "hd44780-low.h"
 #include "lpt-port.h"
-
 #include "report.h"
 
-#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include <usb.h>
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <fcntl.h>
-
 #include <errno.h>
 
 #ifdef HAVE_CONFIG_H
