@@ -1,8 +1,6 @@
 #ifndef LB216_H
 #define LB216_H
 
-#include "lcd.h"
-
 MODULE_EXPORT int  LB216_init(Driver *drvthis);
 MODULE_EXPORT void LB216_close(Driver *drvthis);
 MODULE_EXPORT int  LB216_width (Driver *drvthis);
@@ -14,12 +12,12 @@ MODULE_EXPORT void LB216_flush(Driver *drvthis);
 MODULE_EXPORT void LB216_string (Driver *drvthis, int x, int y, const char string[]);
 MODULE_EXPORT void LB216_chr(Driver *drvthis, int x, int y, char c) ;
 
-MODULE_EXPORT void LB216_old_vbar(Driver *drvthis, int x, int len);
-MODULE_EXPORT void LB216_old_hbar(Driver *drvthis, int x, int y, int len);
+MODULE_EXPORT void LB216_vbar(Driver *drvthis, int x, int y, int len, int promille, int options);
+MODULE_EXPORT void LB216_hbar(Driver *drvthis, int x, int y, int len, int promille, int options);
 MODULE_EXPORT void LB216_num(Driver *drvthis, int x, int num);
 MODULE_EXPORT int  LB216_icon(Driver *drvthis, int x, int y, int icon);
 
-MODULE_EXPORT void LB216_set_char(Driver *drvthis, int n, char *dat);
+MODULE_EXPORT void LB216_set_char(Driver *drvthis, int n, unsigned char *dat);
 
 MODULE_EXPORT void LB216_backlight(Driver *drvthis, int on);
 
